IDOffset class

An immutable set of offset in each of the four cardinal directions.

Constructors

IDOffset.horizontal(double horizontal)
const
IDOffset.only({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0})
const

Properties

bottom → double
The offset from the bottom.
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
The offset from the left.
final
The offset from the right.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
The offset from the top.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited