InnerDrawer class

Inheritance

Constructors

InnerDrawer({GlobalKey<State<StatefulWidget>>? key, Widget? leftChild, Widget? rightChild, required Widget scaffold, IDOffset offset = const IDOffset.horizontal(0.4), IDOffset scale = const IDOffset.horizontal(1), bool proportionalChildArea = true, double borderRadius = 0, bool onTapClose = false, bool tapScaffoldEnabled = false, bool swipe = true, bool swipeChild = false, Duration? duration, double velocity = 1, List<BoxShadow>? boxShadow, Color? colorTransitionChild, Color? colorTransitionScaffold, InnerDrawerAnimation leftAnimationType = InnerDrawerAnimation.static, InnerDrawerAnimation rightAnimationType = InnerDrawerAnimation.static, Decoration? backgroundDecoration, InnerDrawerCallback? innerDrawerCallback, InnerDragUpdateCallback? onDragUpdate})
const

Properties

backgroundDecoration → Decoration?
Color of the main background
final
borderRadius → double
edge radius when opening the scaffold - (defalut 0)
final
boxShadow → List<BoxShadow>?
BoxShadow of scaffold open
final
colorTransitionChild → Color?
Color of gradient background
final
colorTransitionScaffold → Color?
Color of gradient background
final
duration → Duration?
duration animation controller
final
hashCode → int
The hash code for this object.
no setterinherited
innerDrawerCallback → InnerDrawerCallback?
Optional callback that is called when a InnerDrawer is open or closed.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftAnimationType → InnerDrawerAnimation
Static or Linear or Quadratic
final
leftChild → Widget?
Left child
final
offset → IDOffset
When the InnerDrawer is open, it's possible to set the offset of each of the four cardinal directions
final
onDragUpdate → InnerDragUpdateCallback?
when a pointer that is in contact with the screen and moves to the right or left
final
onTapClose → bool
Closes the open scaffold
final
proportionalChildArea → bool
The proportionalChild Area = true dynamically sets the width based on the selected offset. On false it leaves the width at 100% of the screen
final
rightAnimationType → InnerDrawerAnimation
Static or Linear or Quadratic
final
rightChild → Widget?
Right child
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffold → Widget
A Scaffold is generally used but you are free to use other widgets
final
scale → IDOffset
When the InnerDrawer is open to the left or to the right values between 1 and 0. (default 1)
final
swipe → bool
activate or deactivate the swipe. NOTE: when deactivate, onTap Close is implicitly activated
final
swipeChild → bool
activate or deactivate the swipeChild. NOTE: when deactivate, onTap Close is implicitly activated
final
tapScaffoldEnabled → bool
Closes the open scaffold
final
velocity → double
possibility to set the opening and closing velocity
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → InnerDrawerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited